@@ -13,13 +13,14 @@ use strict;
 use warnings;
 
 use Net::SMTP;
+use Authen::SASL qw(Perl);
 
 our @ObjectDependencies = (
     'Kernel::Config',
-    'Kernel::System::DB',
     'Kernel::System::Encode',
     'Kernel::System::Log',
-    'Kernel::System::CommunicationLog',
+    'Kernel::System::OAuth2Token',
+    'Kernel::System::OAuth2TokenConfig',
 );
 
 sub new {
@@ -38,6 +39,7 @@ sub new {
     }
 
     ( $Self->{SMTPType} ) = ( $Type =~ m/::Email::(.*)$/i );
+    $Self->{EmailModuleName} = $Self->_GetEmailModuleName();
 
     return $Self;
 }
@@ -69,14 +71,17 @@ sub Check {
     $Self->{FQDN}     = $ConfigObject->Get('FQDN');
     $Self->{MailHost} = $ConfigObject->Get('SendmailModule::Host')
         || die "No SendmailModule::Host found in Kernel/Config.pm";
-    $Self->{SMTPPort} = $ConfigObject->Get('SendmailModule::Port');
-    $Self->{User}     = $ConfigObject->Get('SendmailModule::AuthUser');
-    $Self->{Password} = $ConfigObject->Get('SendmailModule::AuthPassword');
+    $Self->{SMTPPort}              = $ConfigObject->Get('SendmailModule::Port');
+    $Self->{Timeout}               = $ConfigObject->Get('SendmailModule::Timeout');
+    $Self->{User}                  = $ConfigObject->Get('SendmailModule::AuthUser');
+    $Self->{Password}              = $ConfigObject->Get('SendmailModule::AuthPassword');
+    $Self->{AuthenticationType}    = $ConfigObject->Get('SendmailModule::AuthenticationType') // 'password';
+    $Self->{OAuth2TokenConfigName} = $ConfigObject->Get('SendmailModule::OAuth2TokenConfigName');
 
     $Param{CommunicationLogObject}->ObjectLog(
         ObjectLogType => 'Connection',
         Priority      => 'Debug',
-        Key           => 'Kernel::System::Email::SMTP',
+        Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
         Value         => 'Testing connection to SMTP service (3 attempts max.).',
     );
 
@@ -96,7 +101,7 @@ sub Check {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Connection',
             Priority      => 'Debug',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => sprintf( $TryConnectMessage, $Try, ),
         );
 
@@ -106,6 +111,7 @@ sub Check {
                 MailHost  => $Self->{MailHost},
                 FQDN      => $Self->{FQDN},
                 SMTPPort  => $Self->{SMTPPort},
+                Timeout   => $Self->{Timeout},
                 SMTPDebug => $Self->{SMTPDebug},
             );
             return 1;
@@ -126,7 +132,7 @@ sub Check {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Connection',
             Priority      => 'Debug',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => "$Try: Connection could not be established. Waiting for 0.3 seconds.",
         );
 
@@ -140,7 +146,7 @@ sub Check {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Connection',
             Priority      => 'Error',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => "Could not connect to host '$Self->{MailHost}'. ErrorMessage: $!",
         );
 
@@ -154,35 +160,97 @@ sub Check {
         SMTP => $SMTP,
     );
 
-    # use smtp auth if configured
-    if ( $Self->{User} && $Self->{Password} ) {
+    # Set authentication to successful by default because it was the default before,
+    # without the changes made here. This is needed to be able to use SMTP without any
+    # configured authentication.
+    my $AuthenticationSuccessful = 1;
+
+    if (
+        $Self->{AuthenticationType} eq 'password'
+        && $Self->{User}
+        && $Self->{Password}
+        )
+    {
+        $Param{CommunicationLogObject}->ObjectLog(
+            ObjectLogType => 'Connection',
+            Priority      => 'Debug',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
+            Value         => "Using SMTP authentication with user '$Self->{User}' and (hidden) password.",
+        );
+
+        $AuthenticationSuccessful = $SMTP->( 'auth', $Self->{User}, $Self->{Password} );
+    }
+    elsif ( $Self->{AuthenticationType} eq 'oauth2_token' ) {
+        if ( !$Self->{OAuth2TokenConfigName} ) {
+            return $ReturnError->(
+                ErrorMessage => 'SysConfig option SendmailModule::OAuth2TokenConfigName is not set.',
+                Code         => 0,
+            );
+        }
+        my $OAuth2TokenConfigObject = $Kernel::OM->Get('Kernel::System::OAuth2TokenConfig');
+
+        my %OAuth2TokenConfig = $OAuth2TokenConfigObject->DataGet(
+            Name   => $Self->{OAuth2TokenConfigName},
+            UserID => 1,
+        );
+        if ( !%OAuth2TokenConfig ) {
+            return $ReturnError->(
+                ErrorMessage => "OAuth2 token config with name '$Self->{OAuth2TokenConfigName}' could not be found.",
+                Code         => 0,
+            );
+        }
+
+        my $OAuth2TokenObject = $Kernel::OM->Get('Kernel::System::OAuth2Token');
+
+        my $OAuth2Token = $OAuth2TokenObject->GetToken(
+            TokenConfigID => $OAuth2TokenConfig{ $OAuth2TokenConfigObject->{Identifier} },
+            UserID        => 1,
+        );
+        if ( !$OAuth2Token ) {
+            return $ReturnError->(
+                ErrorMessage =>
+                    "OAuth2 token for config with name '$Self->{OAuth2TokenConfigName}' could not be retrieved.",
+                Code => 0,
+            );
+        }
 
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Connection',
             Priority      => 'Debug',
-            Key           => 'Kernel::System::Email::SMTP',
-            Value         => "Using SMTP authentication with user '$Self->{User}' and (hidden) password.",
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
+            Value =>
+                "Using SMTP authentication with user '$Self->{User}' and OAuth2 token config '$Self->{OAuth2TokenConfigName}'.",
         );
 
-        if ( !$SMTP->( 'auth', $Self->{User}, $Self->{Password} ) ) {
+        my $SASLObject = Authen::SASL->new(
+            mechanism => 'XOAUTH2',
+            callback  => {
+                user         => $Self->{User},
+                auth         => 'Bearer',
+                access_token => $OAuth2Token,
+            },
+        );
 
-            my $Code  = $SMTP->( 'code', );
-            my $Error = $Code . ', ' . $SMTP->( 'message', );
+        $AuthenticationSuccessful = $SMTP->( 'auth', $SASLObject );
+    }
 
-            $SMTP->( 'quit', );
+    if ( !$AuthenticationSuccessful ) {
+        my $Code  = $SMTP->( 'code', );
+        my $Error = $Code . ', ' . $SMTP->( 'message', );
 
-            $Param{CommunicationLogObject}->ObjectLog(
-                ObjectLogType => 'Connection',
-                Priority      => 'Error',
-                Key           => 'Kernel::System::Email::SMTP',
-                Value         => "SMTP authentication failed (SMTP code: $Code, ErrorMessage: $Error).",
-            );
+        $SMTP->( 'quit', );
 
-            return $ReturnError->(
-                ErrorMessage => "SMTP authentication failed: $Error!",
-                Code         => $Code,
-            );
-        }
+        $Param{CommunicationLogObject}->ObjectLog(
+            ObjectLogType => 'Connection',
+            Priority      => 'Error',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
+            Value         => "SMTP authentication failed (SMTP code: $Code, ErrorMessage: $Error).",
+        );
+
+        return $ReturnError->(
+            ErrorMessage => "SMTP authentication failed: $Error!",
+            Code         => $Code,
+        );
     }
 
     return $ReturnSuccess->(
@@ -196,7 +264,7 @@ sub Send {
     $Param{CommunicationLogObject}->ObjectLog(
         ObjectLogType => 'Message',
         Priority      => 'Info',
-        Key           => 'Kernel::System::Email::SMTP',
+        Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
         Value         => 'Received message for sending, validating message contents.',
     );
 
@@ -207,7 +275,7 @@ sub Send {
             $Param{CommunicationLogObject}->ObjectLog(
                 ObjectLogType => 'Message',
                 Priority      => 'Error',
-                Key           => 'Kernel::System::Email::SMTP',
+                Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
                 Value         => "Need $Needed!",
             );
 
@@ -234,7 +302,7 @@ sub Send {
     $Param{CommunicationLogObject}->ObjectLog(
         ObjectLogType => 'Message',
         Priority      => 'Debug',
-        Key           => 'Kernel::System::Email::SMTP',
+        Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
         Value         => "Sending envelope from (mail from: $Param{From}) to server.",
     );
 
@@ -251,7 +319,7 @@ sub Send {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Message',
             Priority      => 'Error',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => $FullErrorMessage,
         );
 
@@ -268,7 +336,7 @@ sub Send {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Message',
             Priority      => 'Debug',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => "Sending envelope to (rcpt to: $To) to server.",
         );
 
@@ -285,7 +353,7 @@ sub Send {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Message',
             Priority      => 'Error',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => $FullErrorMessage,
         );
 
@@ -311,7 +379,7 @@ sub Send {
     $Param{CommunicationLogObject}->ObjectLog(
         ObjectLogType => 'Message',
         Priority      => 'Debug',
-        Key           => 'Kernel::System::Email::SMTP',
+        Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
         Value         => "Sending message data to server.",
     );
 
@@ -350,7 +418,7 @@ sub Send {
         $Param{CommunicationLogObject}->ObjectLog(
             ObjectLogType => 'Message',
             Priority      => 'Error',
-            Key           => 'Kernel::System::Email::SMTP',
+            Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
             Value         => $FullErrorMessage,
         );
 
@@ -372,7 +440,7 @@ sub Send {
     $Param{CommunicationLogObject}->ObjectLog(
         ObjectLogType => 'Message',
         Priority      => 'Info',
-        Key           => 'Kernel::System::Email::SMTP',
+        Key           => 'Kernel::System::Email::' . $Self->{EmailModuleName},
         Value         => "Email successfully sent from '$Param{From}' to '$ToString'.",
     );
 
@@ -400,15 +468,27 @@ sub _Connect {
     my $FQDN = $Param{FQDN};
     $FQDN =~ s{:\d+}{}smx;
 
+    my %SSLOptions = $Self->_GetSSLOptions();
+
+    my $SMTPDefaultPort = $Self->_GetSMTPDefaultPort();
+    my $SMTPPort        = $Param{SMTPPort} || $SMTPDefaultPort;
+    my $Timeout         = $Param{Timeout} || 30;
+
     # set up connection connection
     my $SMTP = Net::SMTP->new(
         $Param{MailHost},
-        Hello   => $FQDN,
-        Port    => $Param{SMTPPort} || 25,
-        Timeout => 30,
+        Hello => $FQDN,
+        Port  => $SMTPPort,
+        %SSLOptions,
+        Timeout => $Timeout,
         Debug   => $Param{SMTPDebug},
     );
 
+    my %StartTLSOptions = $Self->_GetStartTLSOptions();
+    if (%StartTLSOptions) {
+        $SMTP->starttls(%StartTLSOptions);
+    }
+
     return $SMTP;
 }
 
@@ -484,4 +564,33 @@ sub _GetSMTPSafeWrapper {
     };
 }
 
+sub _GetSMTPDefaultPort {
+    my ( $Self, %Param ) = @_;
+
+    return 25;
+}
+
+sub _GetSSLOptions {
+    my ( $Self, %Param ) = @_;
+
+    return;
+}
+
+sub _GetStartTLSOptions {
+    my ( $Self, %Param ) = @_;
+
+    return;
+}
+
+sub _GetEmailModuleName {
+    my ( $Self, %Param ) = @_;
+
+    my $PackageName = ref $Self;
+    if ( $PackageName =~ m{\AKernel::System::Email::(.*)\z} ) {
+        $PackageName = $1;
+    }
+
+    return $PackageName;
+}
+
 1;
